==> darcs-2.16.3-138-x86_64.pkg.tar.zst: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 darcs
version:              2.16.3
visibility:           public
id:                   darcs-2.16.3-FYhEFd1VOmeDK1X2l5eTlt
key:                  darcs-2.16.3-FYhEFd1VOmeDK1X2l5eTlt
license:              GPL-2.0-or-later
maintainer:           <darcs-devel@darcs.net>
author:               David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability:            Experimental
homepage:             http://darcs.net/
synopsis:             a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:

    * Distributed: Darcs was one of the first revision control
    systems in which every user has access to the full command
    set, removing boundaries between server and client or
    committer and non-committers.

    * Interactive: Darcs is easy to learn and efficient to use
    because it asks you questions in response to simple
    commands, giving you choices in your work flow. You can
    choose to record one change in a file, while ignoring
    another. As you update from upstream, you can review each
    patch, picking and choosing which patches are appropriate.

    * Smart: Darcs is different from most revision control
    systems in that it is based on the notion of change (or
    patch), rather than version. An underlying algebra of
    patches determines whether changes can be re-ordered. The
    laws of this algebra guarantee that the result of merging
    depends only on the final set of patches applied in a
    repository and not on their order.

    * Simple: As a consequence, Darcs offers a conceptually
    simpler view of the state of a repository: it is given by
    the set of patches it contains. Pulling and pushing
    patches merely transfers them from one set to another. So
    called "cherry-picking" is the default mode of operation,
    and it fully preserves the identity of patches.

category:             Development
abi:                  f314365515cca7456672688b299483af
exposed:              True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Apply
    Darcs.Patch.ApplyMonad Darcs.Patch.ApplyPatches
    Darcs.Patch.Bracketed Darcs.Patch.Bundle Darcs.Patch.Choices
    Darcs.Patch.Commute Darcs.Patch.CommuteFn
    Darcs.Patch.CommuteNoConflicts Darcs.Patch.Conflict
    Darcs.Patch.Debug Darcs.Patch.Depends Darcs.Patch.Effect
    Darcs.Patch.FileHunk Darcs.Patch.Format Darcs.Patch.FromPrim
    Darcs.Patch.Ident Darcs.Patch.Index.Monad Darcs.Patch.Index.Types
    Darcs.Patch.Info Darcs.Patch.Inspect Darcs.Patch.Invert
    Darcs.Patch.Invertible Darcs.Patch.Match Darcs.Patch.Merge
    Darcs.Patch.MonadProgress Darcs.Patch.Named
    Darcs.Patch.Named.Wrapped Darcs.Patch.PatchInfoAnd
    Darcs.Patch.Permutations Darcs.Patch.Prim Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.FileUUID Darcs.Patch.Prim.FileUUID.Apply
    Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.Named
    Darcs.Patch.Prim.V1 Darcs.Patch.Prim.V1.Apply
    Darcs.Patch.Prim.V1.Coalesce Darcs.Patch.Prim.V1.Commute
    Darcs.Patch.Prim.V1.Core Darcs.Patch.Prim.V1.Details
    Darcs.Patch.Prim.V1.Mangle Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.WithName
    Darcs.Patch.Progress Darcs.Patch.Read Darcs.Patch.Rebase.Change
    Darcs.Patch.Rebase.Fixup Darcs.Patch.Rebase.Legacy.Item
    Darcs.Patch.Rebase.Name Darcs.Patch.Rebase.PushFixup
    Darcs.Patch.Rebase.Suspended Darcs.Patch.RegChars
    Darcs.Patch.Repair Darcs.Patch.RepoPatch Darcs.Patch.RepoType
    Darcs.Patch.Set Darcs.Patch.Show Darcs.Patch.Split
    Darcs.Patch.Summary Darcs.Patch.SummaryData
    Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
    Darcs.Patch.Unwind Darcs.Patch.V1 Darcs.Patch.V1.Apply
    Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Prim
    Darcs.Patch.V1.Read Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing
    Darcs.Patch.V2 Darcs.Patch.V2.Non Darcs.Patch.V2.Prim
    Darcs.Patch.V2.RepoPatch Darcs.Patch.V3 Darcs.Patch.V3.Contexted
    Darcs.Patch.V3.Core Darcs.Patch.V3.Resolution Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Maybe
    Darcs.Patch.Witnesses.Ordered Darcs.Patch.Witnesses.Sealed
    Darcs.Patch.Witnesses.Show Darcs.Patch.Witnesses.Unsafe
    Darcs.Patch.Witnesses.WZipper Darcs.Prelude Darcs.Repository
    Darcs.Repository.ApplyPatches Darcs.Repository.Cache
    Darcs.Repository.Clone Darcs.Repository.Create
    Darcs.Repository.Diff Darcs.Repository.Flags
    Darcs.Repository.Format Darcs.Repository.Hashed
    Darcs.Repository.HashedIO Darcs.Repository.Identify
    Darcs.Repository.InternalTypes Darcs.Repository.Inventory
    Darcs.Repository.Job Darcs.Repository.Match Darcs.Repository.Merge
    Darcs.Repository.Old Darcs.Repository.Packs
    Darcs.Repository.PatchIndex Darcs.Repository.Paths
    Darcs.Repository.Pending Darcs.Repository.Prefs
    Darcs.Repository.Pristine Darcs.Repository.Rebase
    Darcs.Repository.Repair Darcs.Repository.Resolution
    Darcs.Repository.State Darcs.Repository.Test
    Darcs.Repository.Traverse Darcs.Repository.Working
    Darcs.Test.TestOnly Darcs.UI.ApplyPatches Darcs.UI.Commands
    Darcs.UI.Commands.Add Darcs.UI.Commands.Amend
    Darcs.UI.Commands.Annotate Darcs.UI.Commands.Apply
    Darcs.UI.Commands.Clone Darcs.UI.Commands.Convert
    Darcs.UI.Commands.Convert.Darcs2 Darcs.UI.Commands.Convert.Export
    Darcs.UI.Commands.Convert.Import Darcs.UI.Commands.Convert.Util
    Darcs.UI.Commands.Diff Darcs.UI.Commands.Dist
    Darcs.UI.Commands.GZCRCs Darcs.UI.Commands.Help
    Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.TransferMode
    Darcs.UI.Commands.Unrecord Darcs.UI.Commands.Unrevert
    Darcs.UI.Commands.Util Darcs.UI.Commands.Util.Tree
    Darcs.UI.Commands.WhatsNew Darcs.UI.Completion Darcs.UI.Defaults
    Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags Darcs.UI.Options
    Darcs.UI.Options.All Darcs.UI.Options.Core Darcs.UI.Options.Flags
    Darcs.UI.Options.Iso Darcs.UI.Options.Markdown
    Darcs.UI.Options.Matching Darcs.UI.Options.Util
    Darcs.UI.PatchHeader Darcs.UI.PrintPatch Darcs.UI.RunCommand
    Darcs.UI.SelectChanges Darcs.UI.TheCommands Darcs.UI.Usage
    Darcs.Util.AtExit Darcs.Util.ByteString Darcs.Util.CommandLine
    Darcs.Util.Compat Darcs.Util.DateMatcher Darcs.Util.DateTime
    Darcs.Util.Diff Darcs.Util.Diff.Myers Darcs.Util.Diff.Patience
    Darcs.Util.Download Darcs.Util.Download.Request Darcs.Util.Encoding
    Darcs.Util.English Darcs.Util.Exception Darcs.Util.Exec
    Darcs.Util.External Darcs.Util.File Darcs.Util.Global
    Darcs.Util.Graph Darcs.Util.HTTP Darcs.Util.Hash Darcs.Util.Index
    Darcs.Util.IsoDate Darcs.Util.Lock Darcs.Util.Parser
    Darcs.Util.Path Darcs.Util.Printer Darcs.Util.Printer.Color
    Darcs.Util.Progress Darcs.Util.Prompt Darcs.Util.Ratified
    Darcs.Util.Show Darcs.Util.SignalHandler Darcs.Util.Ssh
    Darcs.Util.Tree Darcs.Util.Tree.Hashed Darcs.Util.Tree.Monad
    Darcs.Util.Tree.Plain Darcs.Util.URL Darcs.Util.Workaround

hidden-modules:       Version Darcs.Util.Download.Curl
import-dirs:          /usr/lib/ghc-8.10.4/site-local/darcs-2.16.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/darcs-2.16.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/darcs-2.16.3
hs-libraries:         HSdarcs-2.16.3-FYhEFd1VOmeDK1X2l5eTlt
extra-libraries:      curl
depends:
    array-0.5.4.0 async-2.2.3-bRJqoep3gj749cy8sss28
    attoparsec-0.14.1-DGdxWuqth0ECkVhd5culC1 base-4.14.1.0
    base16-bytestring-1.0.1.0-ACAk6UnKid9CJt3stBqH5 binary-0.8.8.0
    bytestring-0.10.12.0 conduit-1.3.4.1-4INmeOUvaDJApsC4CK6uTn
    constraints-0.13-BA0Mdhgg0BF36zW632HSM9 containers-0.6.2.1
    cryptonite-0.29-L3U8rsDq0iB1yqr8e7PodL
    data-ordlist-0.4.7.0-2kQWNKO9R932B0kq2odINA directory-1.3.6.0
    fgl-5.7.0.3-9tiCr9w0jR9JDe073Qsr0h filepath-1.4.2.1
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh haskeline-0.8.0.1
    html-1.0.1.2-C5vyTPgyVcWHiWuHJSHlFK
    http-conduit-2.3.8-Fr1aXfOubCsAgGM46lSV3o
    http-types-0.12.3-A295xIncU4UGWNjKZ5JlYY
    memory-0.16.0-FcR25XxjAGsCy9iFRDcpya
    mmap-0.5.9-AeMhBFCLycRGGScmgorM0n mtl-2.2.2
    network-3.1.2.1-55GjX5DAoUc4xkfPAxcpEj
    network-uri-2.6.4.1-1BmCyGgbb9xCyfeFepQNgy
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK parsec-3.1.14.0
    process-1.6.9.0 regex-applicative-0.3.4-JyFmC0T7jhbFXTPyTBUyXc
    regex-compat-tdfa-0.95.1.4-JDz7VoeUX4VBXivyiuUP3o stm-2.5.0.0
    tar-0.5.1.1-L5ktp1wUFbZ4KB26PJOsIr
    temporary-1.3-HbVp7bABqm33Wq1BFsPnZt terminfo-0.4.1.4 text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-IwaLbQErzPq95Qm3ml0M2u
    zip-archive-0.4.1-2yHLjFlYM0xDhZAoSlZ1hy
    zlib-0.6.2.3-Hqwhl8hfUo0E76lQu8Fk8k

haddock-interfaces:   /usr/share/doc/darcs/html/darcs.haddock
haddock-html:         /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> darcs-2.16.4-5-x86_64.pkg.tar.zst: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 darcs
version:              2.16.4
visibility:           public
id:                   darcs-2.16.4-2BPLPiQYFlDLaPNnW6QTUl
key:                  darcs-2.16.4-2BPLPiQYFlDLaPNnW6QTUl
license:              GPL-2.0-or-later
maintainer:           <darcs-devel@darcs.net>
author:               David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability:            Experimental
homepage:             http://darcs.net/
synopsis:             a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:

    * Distributed: Darcs was one of the first revision control
    systems in which every user has access to the full command
    set, removing boundaries between server and client or
    committer and non-committers.

    * Interactive: Darcs is easy to learn and efficient to use
    because it asks you questions in response to simple
    commands, giving you choices in your work flow. You can
    choose to record one change in a file, while ignoring
    another. As you update from upstream, you can review each
    patch, picking and choosing which patches are appropriate.

    * Smart: Darcs is different from most revision control
    systems in that it is based on the notion of change (or
    patch), rather than version. An underlying algebra of
    patches determines whether changes can be re-ordered. The
    laws of this algebra guarantee that the result of merging
    depends only on the final set of patches applied in a
    repository and not on their order.

    * Simple: As a consequence, Darcs offers a conceptually
    simpler view of the state of a repository: it is given by
    the set of patches it contains. Pulling and pushing
    patches merely transfers them from one set to another. So
    called "cherry-picking" is the default mode of operation,
    and it fully preserves the identity of patches.

category:             Development
abi:                  54a772a33e614af1bfa576dec53d6016
exposed:              True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Apply
    Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed Darcs.Patch.Bundle
    Darcs.Patch.Choices Darcs.Patch.Commute Darcs.Patch.CommuteFn
    Darcs.Patch.CommuteNoConflicts Darcs.Patch.Conflict
    Darcs.Patch.Debug Darcs.Patch.Depends Darcs.Patch.Effect
    Darcs.Patch.FileHunk Darcs.Patch.Format Darcs.Patch.FromPrim
    Darcs.Patch.Ident Darcs.Patch.Index.Monad Darcs.Patch.Index.Types
    Darcs.Patch.Info Darcs.Patch.Inspect Darcs.Patch.Invert
    Darcs.Patch.Invertible Darcs.Patch.Match Darcs.Patch.Merge
    Darcs.Patch.MonadProgress Darcs.Patch.Named
    Darcs.Patch.Named.Wrapped Darcs.Patch.PatchInfoAnd
    Darcs.Patch.Permutations Darcs.Patch.Prim Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.FileUUID Darcs.Patch.Prim.FileUUID.Apply
    Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.Named
    Darcs.Patch.Prim.V1 Darcs.Patch.Prim.V1.Apply
    Darcs.Patch.Prim.V1.Coalesce Darcs.Patch.Prim.V1.Commute
    Darcs.Patch.Prim.V1.Core Darcs.Patch.Prim.V1.Details
    Darcs.Patch.Prim.V1.Mangle Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.WithName
    Darcs.Patch.Progress Darcs.Patch.Read Darcs.Patch.Rebase.Change
    Darcs.Patch.Rebase.Fixup Darcs.Patch.Rebase.Legacy.Item
    Darcs.Patch.Rebase.Name Darcs.Patch.Rebase.PushFixup
    Darcs.Patch.Rebase.Suspended Darcs.Patch.RegChars
    Darcs.Patch.Repair Darcs.Patch.RepoPatch Darcs.Patch.RepoType
    Darcs.Patch.Set Darcs.Patch.Show Darcs.Patch.Split
    Darcs.Patch.Summary Darcs.Patch.SummaryData
    Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
    Darcs.Patch.Unwind Darcs.Patch.V1 Darcs.Patch.V1.Apply
    Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Prim
    Darcs.Patch.V1.Read Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing
    Darcs.Patch.V2 Darcs.Patch.V2.Non Darcs.Patch.V2.Prim
    Darcs.Patch.V2.RepoPatch Darcs.Patch.V3 Darcs.Patch.V3.Contexted
    Darcs.Patch.V3.Core Darcs.Patch.V3.Resolution Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Maybe
    Darcs.Patch.Witnesses.Ordered Darcs.Patch.Witnesses.Sealed
    Darcs.Patch.Witnesses.Show Darcs.Patch.Witnesses.Unsafe
    Darcs.Patch.Witnesses.WZipper Darcs.Prelude Darcs.Repository
    Darcs.Repository.ApplyPatches Darcs.Repository.Cache
    Darcs.Repository.Clone Darcs.Repository.Create
    Darcs.Repository.Diff Darcs.Repository.Flags
    Darcs.Repository.Format Darcs.Repository.Hashed
    Darcs.Repository.HashedIO Darcs.Repository.Identify
    Darcs.Repository.InternalTypes Darcs.Repository.Inventory
    Darcs.Repository.Job Darcs.Repository.Match Darcs.Repository.Merge
    Darcs.Repository.Old Darcs.Repository.Packs
    Darcs.Repository.PatchIndex Darcs.Repository.Paths
    Darcs.Repository.Pending Darcs.Repository.Prefs
    Darcs.Repository.Pristine Darcs.Repository.Rebase
    Darcs.Repository.Repair Darcs.Repository.Resolution
    Darcs.Repository.State Darcs.Repository.Test
    Darcs.Repository.Traverse Darcs.Repository.Working
    Darcs.Test.TestOnly Darcs.UI.ApplyPatches Darcs.UI.Commands
    Darcs.UI.Commands.Add Darcs.UI.Commands.Amend
    Darcs.UI.Commands.Annotate Darcs.UI.Commands.Apply
    Darcs.UI.Commands.Clone Darcs.UI.Commands.Convert
    Darcs.UI.Commands.Convert.Darcs2 Darcs.UI.Commands.Convert.Export
    Darcs.UI.Commands.Convert.Import Darcs.UI.Commands.Convert.Util
    Darcs.UI.Commands.Diff Darcs.UI.Commands.Dist
    Darcs.UI.Commands.GZCRCs Darcs.UI.Commands.Help
    Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.TransferMode
    Darcs.UI.Commands.Unrecord Darcs.UI.Commands.Unrevert
    Darcs.UI.Commands.Util Darcs.UI.Commands.Util.Tree
    Darcs.UI.Commands.WhatsNew Darcs.UI.Completion Darcs.UI.Defaults
    Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags Darcs.UI.Options
    Darcs.UI.Options.All Darcs.UI.Options.Core Darcs.UI.Options.Flags
    Darcs.UI.Options.Iso Darcs.UI.Options.Markdown
    Darcs.UI.Options.Matching Darcs.UI.Options.Util
    Darcs.UI.PatchHeader Darcs.UI.PrintPatch Darcs.UI.RunCommand
    Darcs.UI.SelectChanges Darcs.UI.TheCommands Darcs.UI.Usage
    Darcs.Util.AtExit Darcs.Util.ByteString Darcs.Util.CommandLine
    Darcs.Util.Compat Darcs.Util.DateMatcher Darcs.Util.DateTime
    Darcs.Util.Diff Darcs.Util.Diff.Myers Darcs.Util.Diff.Patience
    Darcs.Util.Download Darcs.Util.Download.Request Darcs.Util.Encoding
    Darcs.Util.English Darcs.Util.Exception Darcs.Util.Exec
    Darcs.Util.External Darcs.Util.File Darcs.Util.Global
    Darcs.Util.Graph Darcs.Util.HTTP Darcs.Util.Hash Darcs.Util.Index
    Darcs.Util.IsoDate Darcs.Util.Lock Darcs.Util.Parser
    Darcs.Util.Path Darcs.Util.Printer Darcs.Util.Printer.Color
    Darcs.Util.Progress Darcs.Util.Prompt Darcs.Util.Ratified
    Darcs.Util.Show Darcs.Util.SignalHandler Darcs.Util.Ssh
    Darcs.Util.Tree Darcs.Util.Tree.Hashed Darcs.Util.Tree.Monad
    Darcs.Util.Tree.Plain Darcs.Util.URL Darcs.Util.Workaround

hidden-modules:       Version Darcs.Util.Download.Curl
import-dirs:          /usr/lib/ghc-8.10.4/site-local/darcs-2.16.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/darcs-2.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/darcs-2.16.4
hs-libraries:         HSdarcs-2.16.4-2BPLPiQYFlDLaPNnW6QTUl
extra-libraries:      curl
depends:
    array-0.5.4.0 async-2.2.3-DvF9gf9qyfPK6D6feIe45y
    attoparsec-0.14.1-94M7XwbxYJLFvYthp17dR base-4.14.1.0
    base16-bytestring-1.0.1.0-GFHbp9pDGKb7zba4QjzG5A binary-0.8.8.0
    bytestring-0.10.12.0 conduit-1.3.4.1-74EEN6J9iPp6XmuhFTF6tG
    constraints-0.13-9n7jZlhWV6gFT5dthV8OjE containers-0.6.2.1
    cryptonite-0.29-2DlnxXwX1G4IdMr893KKKJ
    data-ordlist-0.4.7.0-2kQWNKO9R932B0kq2odINA directory-1.3.6.0
    fgl-5.7.0.3-3XtgKPnbxjJ479ATcsW3Ko filepath-1.4.2.1
    hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R haskeline-0.8.0.1
    html-1.0.1.2-C5vyTPgyVcWHiWuHJSHlFK
    http-conduit-2.3.8-D9dVOmx4VoE15jNSJK49tg
    http-types-0.12.3-COhfNYEpiaQFi7TclzTcwh
    memory-0.16.0-FcR25XxjAGsCy9iFRDcpya
    mmap-0.5.9-AeMhBFCLycRGGScmgorM0n mtl-2.2.2
    network-3.1.2.1-JWsgyzxIkceBMW0wbRjAeX
    network-uri-2.6.4.1-1oGYEtCGxwGIDetCtBI9bJ
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK parsec-3.1.14.0
    process-1.6.9.0 regex-applicative-0.3.4-4aIDfS2I6T6KULdW01lKiF
    regex-compat-tdfa-0.95.1.4-JDz7VoeUX4VBXivyiuUP3o stm-2.5.0.0
    tar-0.5.1.1-1vXfEdnqEYrGmFddjWKQX8
    temporary-1.3-KC4hzhhdTjkLpKRrIYU7kN terminfo-0.4.1.4 text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-HURuJbi2iJT3pZcjBMuHYu
    zip-archive-0.4.1-Ke6xissTp9F3xaNX2vVx9L
    zlib-0.6.2.3-C5uBsvkye3VLX7pTj027ns

haddock-interfaces:   /usr/share/doc/darcs/html/darcs.haddock
haddock-html:         /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
